==> polars_genson-0.1.9.tar.gz: polars_genson-0.1.9/polars-jsonschema-bridge/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.7](https://github.com/lmmx/polars-genson/compare/polars-jsonschema-bridge-v0.1.6...polars-jsonschema-bridge-v0.1.7) - 2025-09-10

### <!-- 4 -->Documentation

- README updates for polars-jsonschema-bridge crate (belated for v0.1.6)

## [0.1.6](https://github.com/lmmx/polars-genson/compare/polars-jsonschema-bridge-v0.1.5...polars-jsonschema-bridge-v0.1.6) - 2025-09-09

### <!-- 9 -->Other

- avsc polars decode ([#60](https://github.com/lmmx/polars-genson/pull/60))

## [0.1.3](https://github.com/lmmx/polars-genson/compare/polars-jsonschema-bridge-v0.1.2...polars-jsonschema-bridge-v0.1.3) - 2025-09-06

### <!-- 1 -->Features

- *(serialisation)* working extension MVP ([#17](https://github.com/lmmx/polars-genson/pull/17))
- *(serialise)* implement Polars schema to JSON ([#16](https://github.com/lmmx/polars-genson/pull/16))

## [0.1.2](https://github.com/lmmx/polars-genson/compare/polars-jsonschema-bridge-v0.1.1...polars-jsonschema-bridge-v0.1.2) - 2025-08-20

### <!-- 4 -->Documentation

- give all crates decent READMEs ([#14](https://github.com/lmmx/polars-genson/pull/14))

## [0.1.1](https://github.com/lmmx/polars-genson/compare/polars-jsonschema-bridge-v0.1.0...polars-jsonschema-bridge-v0.1.1) - 2025-08-20

### <!-- 9 -->Other

- update Cargo.toml dependencies

## [0.1.0](https://github.com/lmmx/polars-genson/releases/tag/polars-jsonschema-bridge-v0.1.0) - 2025-08-20

### <!-- 5 -->Refactor

- *(bridge)* Polars-JSON conversion code ([#10](https://github.com/lmmx/polars-genson/pull/10))
- *(rename)* 'infer_schema' to 'infer_json_schema' ([#6](https://github.com/lmmx/polars-genson/pull/6))

### <!-- 9 -->Other

- amend release process and do a dry run
- new package and version bumps ([#5](https://github.com/lmmx/polars-genson/pull/5))

==> polars_genson-0.5.8.tar.gz: polars_genson-0.5.8/polars-jsonschema-bridge/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.5.1](https://github.com/lmmx/polars-genson/compare/polars-jsonschema-bridge-v0.5.0...polars-jsonschema-bridge-v0.5.1) - 2025-10-08

### <!-- 9 -->Other

- update Cargo.toml dependencies

## [0.1.7](https://github.com/lmmx/polars-genson/compare/polars-jsonschema-bridge-v0.1.6...polars-jsonschema-bridge-v0.1.7) - 2025-09-10

### <!-- 4 -->Documentation

- README updates for polars-jsonschema-bridge crate (belated for v0.1.6)

## [0.1.6](https://github.com/lmmx/polars-genson/compare/polars-jsonschema-bridge-v0.1.5...polars-jsonschema-bridge-v0.1.6) - 2025-09-09

### <!-- 9 -->Other

- avsc polars decode ([#60](https://github.com/lmmx/polars-genson/pull/60))

## [0.1.3](https://github.com/lmmx/polars-genson/compare/polars-jsonschema-bridge-v0.1.2...polars-jsonschema-bridge-v0.1.3) - 2025-09-06

### <!-- 1 -->Features

- *(serialisation)* working extension MVP ([#17](https://github.com/lmmx/polars-genson/pull/17))
- *(serialise)* implement Polars schema to JSON ([#16](https://github.com/lmmx/polars-genson/pull/16))

## [0.1.2](https://github.com/lmmx/polars-genson/compare/polars-jsonschema-bridge-v0.1.1...polars-jsonschema-bridge-v0.1.2) - 2025-08-20

### <!-- 4 -->Documentation

- give all crates decent READMEs ([#14](https://github.com/lmmx/polars-genson/pull/14))

## [0.1.1](https://github.com/lmmx/polars-genson/compare/polars-jsonschema-bridge-v0.1.0...polars-jsonschema-bridge-v0.1.1) - 2025-08-20

### <!-- 9 -->Other

- update Cargo.toml dependencies

## [0.1.0](https://github.com/lmmx/polars-genson/releases/tag/polars-jsonschema-bridge-v0.1.0) - 2025-08-20

### <!-- 5 -->Refactor

- *(bridge)* Polars-JSON conversion code ([#10](https://github.com/lmmx/polars-genson/pull/10))
- *(rename)* 'infer_schema' to 'infer_json_schema' ([#6](https://github.com/lmmx/polars-genson/pull/6))

### <!-- 9 -->Other

- amend release process and do a dry run
- new package and version bumps ([#5](https://github.com/lmmx/polars-genson/pull/5))
